# Euphonium ![License: CC BY-ND 4.0](https://img.shields.io/badge/License-CC%20BY--ND%204.0-lightgrey.svg)

@ Copyright (C) 2024, Void Echo


Contemporary Python Utilities for Deep Learning Applications
